@@ -2,41 +2,24 @@ import re
 import os
 import json
 import logging
-import tempfile
-import urllib.parse
 import gzip
 import bz2
 import zstandard as zstd
 import xml.etree.ElementTree as ET
-from typing import List
 from tempfile import TemporaryDirectory
-from typing import Generator
 from pathlib import Path
-import git
 import requests
-from bs4 import BeautifulSoup
 import traceback
 import functools
 import inspect
-from typing import Callable, Any
-from typing import List, Dict, Any, Optional
-
+from typing import Callable,List, Any, Generator, Tuple
 import requests.exceptions
-from typing import Generator, Optional,Tuple
 
 log=logging.getLogger(__name__)
 
 def enter_and_leave_function(func: Callable) -> Callable:
-    """
-    函数调用日志装饰器：
-    1. 记录函数入参、调用位置
-    2. 正常执行时记录返回值
-    3. 异常时记录完整堆栈（含函数内具体报错行数）
-    """
-
-    @functools.wraps(func)  # 保留原函数元信息（如 __name__、__doc__）
+    @functools.wraps(func)
     def wrapper(*args: Any, **kwargs: Any) -> Any:
-        # 获取函数定义的文件路径和行号（基础位置信息）
         func_def_file = inspect.getsourcefile(func) or "unknown_file"
         func_def_file = func_def_file.split("/")[-1]
         func_def_line = inspect.getsourcelines(func)[1] if func_def_file != "unknown_file" else "unknown_line"
@@ -63,9 +46,9 @@ def enter_and_leave_function(func: Callable) -> Callable:
                 f"| error_type：{type(e).__name__} "
                 f"| error_message：{str(e)} "
                 f"| full_stack_trace：\n{error_traceback}",
-                exc_info=False  # 已手动捕获堆栈，避免 logging 重复打印
+                exc_info=False
             )
-            raise  # 重新抛出异常，不中断原异常链路
+            raise
 
     return wrapper
 
@@ -75,12 +58,6 @@ class Gitee():
         self.__access_token="aa6cb32539129acf5605793f91a1588c"
 
     def get_branches_list_by_repo(self,repo_name,owner_name):
-        """
-        获取仓库的所有分支
-        :param repo_name: 仓库名称
-        :param owner_name: 仓库所属空间地址(企业、组织或个人的地址
-        :return:
-        """
         url = f"{self.__base_url}/repos/{owner_name}/{repo_name}/branches"
         page=1
         parameters={
@@ -147,31 +124,22 @@ class Gitee():
 
 class RepoRpmParser:
     def __init__(self):
-        # 支持的primary.xml压缩格式（优先级从高到低）
         self.compressed_patterns = {
             "zst": re.compile(r'primary\.xml\.zst', re.I),
             "gz": re.compile(r'primary\.xml\.gz', re.I),
             "bz2": re.compile(r'primary\.xml\.bz2', re.I)
         }
-        # RPM元数据命名空间（覆盖默认命名空间+rpm前缀）
         self.ns_map = {
             "rpm": "http://linux.duke.edu/metadata/rpm",
             "default": "http://linux.duke.edu/metadata/common"
         }
 
     def _get_repodata_file_list(self, repodata_url: str) -> List[str]:
-        """
-        获取repodata目录下的文件列表
-        :param repodata_url: repodata目录URL（如 https://xxx/repodata/）
-        :return: 文件名称列表
-        """
         try:
             resp = requests.get(repodata_url, timeout=30)
             resp.raise_for_status()
-            # 适配Apache/Nginx索引页格式，提取primary.xml相关文件
             file_pattern = re.compile(r'href="([a-f0-9]+-primary\.xml(\.[a-z0-9]+)?)"')
             files = file_pattern.findall(resp.text)
-            # 去重并返回完整文件名
             file_list = list({f[0] for f in files})
             log.debug(f"Found repodata files: {file_list}")
             return file_list
@@ -180,12 +148,6 @@ class RepoRpmParser:
             return []
 
     def _download_file(self, file_url: str, save_path: str) -> bool:
-        """
-        下载文件到指定路径（流式下载，支持大文件）
-        :param file_url: 文件URL
-        :param save_path: 本地保存路径
-        :return: 下载成功返回True，失败返回False
-        """
         try:
             resp = requests.get(file_url, stream=True, timeout=60)
             resp.raise_for_status()
@@ -200,12 +162,6 @@ class RepoRpmParser:
             return False
 
     def _decompress_file(self, compressed_path: str, output_path: str) -> bool:
-        """
-        根据文件后缀解压压缩包（支持zst/gz/bz2）
-        :param compressed_path: 压缩文件路径
-        :param output_path: 解压后输出路径
-        :return: 解压成功返回True，失败返回False
-        """
         try:
             if compressed_path.endswith('.zst'):
                 with open(compressed_path, 'rb') as f_in:
@@ -230,44 +186,26 @@ class RepoRpmParser:
             return False
 
     def _parse_primary_xml(self, xml_path: str) -> List[str]:
-        """
-        解析primary.xml文件（兼容命名空间），提取所有RPM包名并去重
-        :param xml_path: primary.xml文件路径
-        :return: 去重后的RPM包名列表
-        """
         rpm_names = set()
         try:
-            # 读取XML文件并处理编码
             with open(xml_path, 'r', encoding='utf-8') as f:
                 xml_content = f.read()
-
-            # 解析XML（处理默认命名空间）
             root = ET.fromstring(xml_content)
-
-            # 方案1：无命名空间的情况（如示例XML）
             packages = root.findall(".//package[@type='rpm']")
-            # 方案2：带默认命名空间的情况
             if not packages:
                 packages = root.findall(".//default:package[@type='rpm']",
                                         namespaces={"default": self.ns_map["default"]})
 
             log.debug(f"Found {len(packages)} RPM packages in primary.xml")
-
-            # 遍历所有package节点提取name
             for pkg in packages:
-                # 尝试直接找name子节点（无命名空间）
                 name_elem = pkg.find("name")
-                # 带默认命名空间的name节点
                 if name_elem is None:
                     name_elem = pkg.find("default:name", namespaces={"default": self.ns_map["default"]})
-
                 if name_elem is not None and name_elem.text:
                     pkg_name = name_elem.text.strip()
-                    if pkg_name:  # 过滤空白包名
+                    if pkg_name:
                         rpm_names.add(pkg_name)
                         log.debug(f"Extracted package name: {pkg_name}")
-
-            # 转有序列表返回
             result = sorted(list(rpm_names))
             log.info(f"Extracted {len(result)} unique RPM package names")
             return result
@@ -280,39 +218,20 @@ class RepoRpmParser:
             return []
 
     def get_rpm_list(self, repo_url: str) -> List[str]:
-        """
-        从指定repo地址获取所有RPM包名列表（去重）
-        核心流程：
-        1. 拼接repodata目录URL
-        2. 探测primary.xml或其压缩包
-        3. 下载并解压（如需）
-        4. 解析XML提取包名并去重
-        :param repo_url: 仓库基础URL（如 https://xxx/openEuler-24.03-LTS-SP2/OS/x86_64/）
-        :return: 去重后的RPM包名列表，失败返回空列表
-        """
         try:
-            # 步骤1：拼接repodata目录URL（处理末尾/）
             repo_url = repo_url.rstrip('/')
             repodata_url = f"{repo_url}/repodata/"
             log.info(f"Start to get RPM list from repo: {repo_url}")
-
-            # 步骤2：获取repodata目录文件列表
             repodata_files = self._get_repodata_file_list(repodata_url)
             if not repodata_files:
                 log.warning(f"No files found in repodata directory: {repodata_url}")
                 return []
-
-            # 步骤3：查找primary.xml或其压缩包
             primary_file = None
             compressed_type = None
-
-            # 优先找未压缩的primary.xml
             for f in repodata_files:
                 if f.endswith('primary.xml'):
                     primary_file = f
                     break
-
-            # 未找到则找压缩包
             if not primary_file:
                 for c_type, pattern in self.compressed_patterns.items():
                     for f in repodata_files:
@@ -328,24 +247,20 @@ class RepoRpmParser:
                 return []
             log.info(f"Found primary file: {primary_file} (compressed type: {compressed_type or 'none'})")
 
-            # 步骤4：临时目录处理文件（自动清理）
             with TemporaryDirectory() as tmp_dir:
                 file_url = f"{repodata_url}/{primary_file}"
                 local_file = os.path.join(tmp_dir, primary_file)
 
-                # 下载文件
                 if not self._download_file(file_url, local_file):
                     return []
 
-                # 解压（如需）
                 xml_path = os.path.join(tmp_dir, 'primary.xml')
                 if compressed_type:
                     if not self._decompress_file(local_file, xml_path):
                         return []
                 else:
-                    xml_path = local_file  # 未压缩直接使用
+                    xml_path = local_file
 
-                # 步骤5：解析XML提取包名
                 rpm_names = self._parse_primary_xml(xml_path)
                 return rpm_names
 
@@ -413,42 +328,14 @@ class OpenEuler():
             self,
             os_version: str
     ) -> Generator[Tuple[str, str], None, None]:
-        """
-        从 Gitee 的 src-openEuler 组织中筛选出包含指定 openEuler 版本分支的仓库信息。
-
-        函数通过调用 Gitee 相关接口，遍历 src-openEuler 组织下的所有仓库，
-        检查仓库是否存在与目标 openEuler 版本匹配的分支，若存在则返回该仓库的名称和 HTML 地址。
-
-        Args:
-            os_version: 目标 openEuler 版本号（如 "24.03-LTS-SP2"），用于匹配仓库分支
-
-        Yields:
-            Generator[Tuple[str, str], None, None]:
-                迭代返回符合条件的仓库信息元组：
-                - 第一个元素：仓库名称（如 "kernel"）
-                - 第二个元素：仓库的 HTML 访问地址（如 "https://gitee.com/src-openEuler/kernel"）
-
-        Notes:
-            依赖 Gitee 类的以下方法：
-            - get_repo_name_and_repo_html_url_by_org(org_name: str): 用于获取指定组织下所有仓库的名称和 HTML 地址
-            - get_branches_list_by_repo(repo_name: str, org_name: str): 用于获取指定仓库的所有分支名称列表
-        """
-        # 初始化 Gitee 接口操作实例
         log.info("正在初始化 Gitee 接口操作实例...")
         gitee = Gitee()
-
-        # 遍历 src-openEuler 组织下的所有仓库（名称 + HTML 地址）
         for repo_name, repo_url in gitee.get_repo_name_and_repo_html_url_by_org("src-openEuler"):
             log.info(f"正在检查仓库: {repo_name}，地址: {repo_url}")
-
-            # 获取当前仓库的所有分支列表
             branches = gitee.get_branches_list_by_repo(repo_name, "src-openEuler")
-            # 处理无分支的异常情况
             if not branches:
                 log.warning(f"仓库 {repo_name}（{repo_url}）未发现任何分支，已跳过")
                 continue
-
-            # 检查目标版本分支是否存在，存在则返回该仓库信息
             branch = f"openEuler-{os_version}"
             if branch in branches:
                 log.info(f"仓库 {repo_name}（{repo_url}）已找到目标版本分支 {branch}")
